@@ -47,8 +47,8 @@ gst_services_tool_class_init (GstServicesToolClass *class)
 static void
 gst_services_tool_init (GstServicesTool *tool)
 {
-	tool->services_config = oobs_services_config_get (GST_TOOL (tool)->session);
-	tool->default_runlevel = oobs_services_config_get_default_runlevel (tool->services_config);
+	tool->services_config = oobs_services_config_get ();
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->services_config);
 }
 
 static void
@@ -88,8 +88,7 @@ gst_services_tool_update_config (GstTool *tool)
 {
 	GstServicesTool *services_tool = GST_SERVICES_TOOL (tool);
 
-	oobs_object_update (services_tool->services_config);
-	services_tool->default_runlevel = oobs_services_config_get_default_runlevel (services_tool->services_config);
+	services_tool->default_runlevel = oobs_services_config_get_default_runlevel (OOBS_SERVICES_CONFIG (services_tool->services_config));
 }
 
 GstTool*
@@ -97,7 +96,7 @@ gst_services_tool_new (void)
 {
 	return g_object_new (GST_TYPE_SERVICES_TOOL,
 			     "name", "services",
-			     "title", _("Services settings"),
-			     "icon", "gnome-fs-server",
+			     "title", _("Services Settings"),
+			     "icon", "network-server",
 			     NULL);
 }
